<h1>Introduction</h1>

Thank you for considering to contribute to the ChromaQuant project! We're super excited to have grabbed your attention. I'm Julia, a research assistant at the University of Washington (UW), Seattle. I'm passionate about sustainability and green chemistry initiatives, and I'm hopeful this project can help with some of those endeavours as well as others. I am also passionate about analytical chemistry and its intersection with data science.

I'm associated with the Rorrer Lab in the Department of Chemical Engineering at UW. You can find more information about our group at https://www.rorrerlab.com!

<h2>Why read these guidelines?</h2>

> I am a huge supporter of collaboration, especially when it comes to academic research. That being said, collaboration depends on predefined expectations and rules. By reading and following these guidelines, you are demonstrating that you respect the work that we do. It is also necessary to get us to address your concerns.

<h2>What contributions are we looking for?</h2>

> ChromaQuant is an open source project for a reason – we want people to both use this project and contribute back to it for an overall improved experience. We are primarily looking for contributions in the form of bug reports and feature recommendations, although writing tutorials and helping others is also encouraged! We are also open to improving our documentation as the project progresses.

<h2>What contributions are we NOT looking for?</h2>

> We are not currently looking for new code at this time. Since this project will be the subject of publications in academic journals, we are looking to maintain control over the exact scripting and functionality of existing code. We are hoping that we'll be able to change this policy in the future, but for the time being please do not initiate pull requests or expect new features to be implemented on a short time scale. Thank you for following this guideline.

<h1>Expectations</h1>

We expect all contributors to adhere to these expectations as well as those outlined in the Code of Conduct:

> 1. Connect with me, Julia, directly using built-in GitHub messaging (or with my personal contact information if we've connected before) before contributing so we can collaborate more effectively. Simple comments or bug reports don't need to follow this rule, although I might reach out for more information!
> 2. If you make tutorials or other contributions to web information, please let me know so I can integrate/adapt to the information that's out there.
> 3. Be welcoming to newcomers and encourage diverse new contributors from all backgrounds – further expectations along this line can be found in the Code of Conduct.

<h1>Conclusions</h1>

I'm very excited to watch this project grow and change and similarly excited to get a chance to work with collaborators across different fields and areas of expertise. In advance of a formal publication on this project, we are not looking for new code or pull requests but instead more indirect bug reports and feature recommendations. Tutorials, and documentation recommendations in some cases, are also encouraged. Please reach out to me over built-in GitHub messaging or through my contact info if you have gotten it previously for any questions or requests to connect. Thank you!
